use clap::Parser;

const REDIRECT_URI: &str = "/redirect";

/// Basic OpenID test client
#[derive(Parser, Debug)]
pub struct AppConfig {
    /// Listen URL
    #[arg(short, long, env, default_value = "0.0.0.0:7510")]
    pub listen_addr: String,

    /// Public URL, the URL where this service is accessible, without the trailing slash
    #[arg(short, long, env, default_value = "http://localhost:7510")]
    pub public_url: String,

    /// URL where the OpenID configuration can be found
    #[arg(short, long, env)]
    pub configuration_url: String,

    /// OpenID client ID
    #[arg(long, env)]
    pub client_id: String,

    /// OpenID client secret
    #[arg(long, env)]
    pub client_secret: String,

    /// Proxy IP, might end with a "*"
    #[clap(long, env)]
    pub proxy_ip: Option<String>,
}

impl AppConfig {
    pub fn get() -> &'static Self {
        &CONF
    }

    pub fn redirect_url(&self) -> String {
        format!("{}{}", self.public_url, REDIRECT_URI)
    }
}

lazy_static::lazy_static! {
    static ref CONF: AppConfig = {
        AppConfig::parse()
    };
}

#[cfg(test)]
mod test {
    use crate::app_config::AppConfig;

    #[test]
    fn verify_cli() {
        use clap::CommandFactory;
        AppConfig::command().debug_assert();
    }
}
